@@ -9,14 +9,18 @@ setGeneric("partition",function(clusters,traj,details=character()){standardGener
 setGeneric("imputation",function(traj,method="copyMean",lowerBound="globalMin",upperBound="globalMax"){standardGeneric("imputation")})
 setGeneric("restoreRealData",function(object){standardGeneric("restoreRealData")})
 setGeneric("expandParLongData",function(xParLongData,y){standardGeneric("expandParLongData")})
-setGeneric("plotTraj",function(x,y,...){standardGeneric("plotTraj")})
+#setGeneric("plotTraj",function(x,y,...){standardGeneric("plotTraj")})
+#setGeneric("plotSenators",function(x,y,...){standardGeneric("plotSenators")})
+#setGeneric("plotMeans",function(x,y,...){standardGeneric("plotMeans")})
 setGeneric("plotTraj3d",function(x,y,...){standardGeneric("plotTraj3d")})
+setGeneric("plotMeans3d",function(x,y,...){standardGeneric("plotMeans3d")})
 setGeneric("plot3dPdf",function(x,y,varY=1,varZ=2){standardGeneric("plot3dPdf")})
 setGeneric("qualityCriterion",function(traj,clusters,imputationMethod="copyMean"){standardGeneric("qualityCriterion")})
-setGeneric("initializePartition",function(nbClusters,lengthPart,method="kmeans++",data){standardGeneric("initializePartition")})
+#setGeneric("initializePartition",function(nbClusters,lengthPart,method="kmeans++",data){standardGeneric("initializePartition")})
 setGeneric("plotCriterion",function(x,criterion=x["criterionActif"],nbCriterion=100){standardGeneric("plotCriterion")})
 setGeneric("plotAllCriterion",function(x,criterion=CRITERION_NAMES[1:5],standardized = TRUE){standardGeneric("plotAllCriterion")})
 
+#setGeneric("getClusters",function(cld, nbCluster, clusterRank = 1, asInteger = FALSE){standardGeneric("getClusters")})
 
 #setGeneric("plotSubGroups",function(x,y,...){standardGeneric("plotSubGroups")})
 #setGeneric("criterion",function(object,partition,method="linearInterpolation"){standardGeneric("criterion")})
